@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-'''
+"""
     :codeauthor: Pedro Algarvio (pedro@algarvio.me)
     :copyright: Copyright 2015 by the SaltStack Team, see AUTHORS for more details.
     :license: Apache 2.0, see LICENSE for more details.
@@ -10,32 +10,34 @@
 
     Simple salt engine which will setup a socket to accept connections allowing us to know
     when a daemon is up and running
-'''
+"""
 
 # Import python libs
 from __future__ import absolute_import, print_function, unicode_literals
-import sys
+
 import errno
-import socket
 import logging
+import os
+import socket
+import sys
+
+import salt.utils.asynchronous
 
 # Import salt libs
 import salt.utils.event
-import salt.utils.asynchronous
 
 # Import 3rd-party libs
-from tornado import gen
-from tornado import ioloop
-from tornado import netutil
-from tornado import iostream
+from salt.ext.tornado import gen, ioloop, iostream, netutil
 
 log = logging.getLogger(__name__)
 
-__virtualname__ = 'salt_runtests'
+__virtualname__ = "salt_runtests"
 
 
 def __virtual__():
-    return 'runtests_conn_check_port' in __opts__  # pylint: disable=undefined-variable
+    if __opts__["__role"] != "master":
+        return False
+    return "runtests_conn_check_port" in __opts__  # pylint: disable=undefined-variable
 
 
 def start():
@@ -47,6 +49,7 @@ class PyTestEngine(object):
     def __init__(self, opts):
         self.opts = opts
         self.sock = None
+        self.stop_sending_events_file = opts.get("pytest_stop_sending_events_file")
 
     def start(self):
         self.io_loop = ioloop.IOLoop()
@@ -56,34 +59,39 @@ class PyTestEngine(object):
 
     @gen.coroutine
     def _start(self):
-        if self.opts['__role'] == 'minion':
-            yield self.listen_to_minion_connected_event()
-        else:
-            self.io_loop.spawn_callback(self.fire_master_started_event)
+        port = int(self.opts["runtests_conn_check_port"])
+        log.info(
+            "Starting Pytest Engine(role=%s, id=%s) on port %s",
+            self.opts["__role"],
+            self.opts["id"],
+            port,
+        )
 
-        port = int(self.opts['runtests_conn_check_port'])
-        log.info('Starting Pytest Engine(role=%s) on port %s', self.opts['__role'], port)
         self.sock = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
         self.sock.setsockopt(socket.SOL_SOCKET, socket.SO_REUSEADDR, 1)
         self.sock.setblocking(0)
         # bind the socket to localhost on the config provided port
-        self.sock.bind(('localhost', port))
+        self.sock.bind(("localhost", port))
         # become a server socket
         self.sock.listen(5)
         with salt.utils.asynchronous.current_ioloop(self.io_loop):
             netutil.add_accept_handler(
-                self.sock,
-                self.handle_connection,
+                self.sock, self.handle_connection,
             )
 
+        if self.opts["__role"] == "master":
+            yield self.fire_master_started_event()
+
     def handle_connection(self, connection, address):
-        log.warning('Accepted connection from %s. Role: %s', address, self.opts['__role'])
+        log.warning(
+            "Accepted connection from %s. Role: %s", address, self.opts["__role"]
+        )
         # We just need to know that the daemon running the engine is alive...
         try:
             connection.shutdown(socket.SHUT_RDWR)  # pylint: disable=no-member
             connection.close()
         except socket.error as exc:
-            if not sys.platform.startswith('darwin'):
+            if not sys.platform.startswith("darwin"):
                 raise
             try:
                 if exc.errno != errno.ENOTCONN:
@@ -92,34 +100,37 @@ class PyTestEngine(object):
                 # This is not macOS !?
                 pass
 
-    @gen.coroutine
-    def listen_to_minion_connected_event(self):
-        log.info('Listening for minion connected event...')
-        minion_start_event_match = 'salt/minion/{0}/start'.format(self.opts['id'])
-        event_bus = salt.utils.event.get_master_event(self.opts, self.opts['sock_dir'], listen=True)
-        event_bus.subscribe(minion_start_event_match)
-        while True:
-            event = event_bus.get_event(full=True, no_block=True)
-            if event is not None and event['tag'] == minion_start_event_match:
-                log.info('Got minion connected event: %s', event)
-                break
-            yield gen.sleep(0.25)
-
     @gen.coroutine
     def fire_master_started_event(self):
-        log.info('Firing salt-master started event...')
-        event_bus = salt.utils.event.get_master_event(self.opts, self.opts['sock_dir'], listen=False)
-        master_start_event_tag = 'salt/master/{0}/start'.format(self.opts['id'])
-        load = {'id': self.opts['id'], 'tag': master_start_event_tag, 'data': {}}
+        log.info("Firing salt-%s started event...", self.opts["__role"])
+        start_event_tag = "salt/{}/{}/start".format(
+            self.opts["__role"], self.opts["id"]
+        )
+        log.info(
+            "Firing salt-%s started event. Tag: %s",
+            self.opts["__role"],
+            start_event_tag,
+        )
+        load = {"id": self.opts["id"], "tag": start_event_tag, "data": {}}
         # One minute should be more than enough to fire these events every second in order
         # for pytest-salt to pickup that the master is running
-        timeout = 60
-        while True:
-            timeout -= 1
-            try:
-                event_bus.fire_event(load, master_start_event_tag, timeout=500)
-                if timeout <= 0:
+        with salt.utils.event.get_master_event(
+            self.opts, self.opts["sock_dir"], listen=False
+        ) as event_bus:
+            timeout = 30
+            while True:
+                if self.stop_sending_events_file and not os.path.exists(
+                    self.stop_sending_events_file
+                ):
+                    log.info(
+                        'The stop sending events file "marker" is done. Stop sending events...'
+                    )
+                    break
+                timeout -= 1
+                try:
+                    event_bus.fire_event(load, start_event_tag, timeout=500)
+                    if timeout <= 0:
+                        break
+                    yield gen.sleep(1)
+                except iostream.StreamClosedError:
                     break
-                yield gen.sleep(1)
-            except iostream.StreamClosedError:
-                break
