@@ -3,26 +3,24 @@
 # Python libs
 from __future__ import absolute_import
 
-# Salt testing libs
-from tests.support.unit import skipIf, TestCase
-from tests.support.mock import NO_MOCK, NO_MOCK_REASON
-from tests.support.mixins import LoaderModuleMockMixin
-
 # Salt libs
 import salt.beacons.avahi_announce as avahi_announce
+from tests.support.mixins import LoaderModuleMockMixin
+
+# Salt testing libs
+from tests.support.unit import TestCase
 
 
-@skipIf(NO_MOCK, NO_MOCK_REASON)
 class AvahiAnnounceBeaconTestCase(TestCase, LoaderModuleMockMixin):
-    '''
+    """
     Test case for salt.beacons.avahi_announce
-    '''
+    """
 
     def setup_loader_modules(self):
         return {
             avahi_announce: {
-                'last_state': {},
-                'last_state_extra': {'no_devices': False}
+                "last_state": {},
+                "last_state_extra": {"no_devices": False},
             }
         }
 
@@ -31,14 +29,21 @@ class AvahiAnnounceBeaconTestCase(TestCase, LoaderModuleMockMixin):
 
         ret = avahi_announce.validate(config)
 
-        self.assertEqual(ret, (False, 'Configuration for avahi_announce'
-                                      ' beacon must be a list.'))
+        self.assertEqual(
+            ret, (False, "Configuration for avahi_announce beacon must be a list.")
+        )
 
     def test_empty_config(self):
         config = [{}]
 
         ret = avahi_announce.validate(config)
 
-        self.assertEqual(ret, (False, 'Configuration for avahi_announce'
-                                      ' beacon must contain servicetype, port'
-                                      ' and txt items.'))
+        self.assertEqual(
+            ret,
+            (
+                False,
+                "Configuration for avahi_announce"
+                " beacon must contain servicetype, port"
+                " and txt items.",
+            ),
+        )
