@@ -568,7 +568,7 @@ class CMDMODTestCase(TestCase, LoaderModuleMockMixin):
         stdout = b"test"
         proc = MagicMock(return_value=MockTimedProc(stdout=stdout))
 
-        msg = "INFO:Executing command 'some command' in directory"
+        msg = "INFO:Executing command 'some' in directory"
         with patch("salt.utils.timed_subprocess.TimedProc", proc):
             with TstSuiteLoggingHandler() as log_handler:
                 ret = cmdmod.run_all("some command", output_loglevel="debug")
@@ -643,11 +643,7 @@ class CMDMODTestCase(TestCase, LoaderModuleMockMixin):
 
     def test_cve_2021_25284(self):
         proc = MagicMock(
-            return_value=MockTimedProc(
-                stdout=b"foo",
-                stderr=b"wtf",
-                returncode=2
-            )
+            return_value=MockTimedProc(stdout=b"foo", stderr=b"wtf", returncode=2)
         )
         with patch("salt.utils.timed_subprocess.TimedProc", proc):
             with TstSuiteLoggingHandler() as log_handler:
