@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-'''
+"""
     :codeauthor: Pedro Algarvio (pedro@algarvio.me)
 
 
@@ -7,20 +7,19 @@
     ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 
     Test salt.utils.immutabletypes
-'''
+"""
 
 # Import Python libs
 from __future__ import absolute_import, unicode_literals
 
-# Import Salt Testing libs
-from tests.support.unit import TestCase
-
 # Import salt libs
 import salt.utils.immutabletypes as immutabletypes
 
+# Import Salt Testing libs
+from tests.support.unit import TestCase
+
 
 class ImmutableTypesTestCase(TestCase):
-
     def test_immutablelist_sum(self):
         lst = [4, 5, 6]
         imt = immutabletypes.ImmutableList([1, 2, 3])
@@ -52,13 +51,9 @@ class ImmutableTypesTestCase(TestCase):
             3: {
                 3.1: 3.1,
                 3.2: 3.2,
-                3.3: {
-                    3.31: 3.33,
-                    3.32: 3.34,
-                    3.33: [3.331, 3.332, 3.333]
-                }
+                3.3: {3.31: 3.33, 3.32: 3.34, 3.33: [3.331, 3.332, 3.333]},
             },
-            4: [4.1, 4.2, 4.3]
+            4: [4.1, 4.2, 4.3],
         }
         frozen = immutabletypes.freeze(data)
         with self.assertRaises(TypeError):
